[Cmake-commits] CMake branch, master, updated. v3.7.0-693-g996e523

2016-11-29 Thread Kitware Robot
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, master has been updated
   via  996e5237cad257b94c55cb788e8175e474b6696f (commit)
  from  44c978a2dab96b44ed2dd7470f532c4aa4c7da7c (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=996e5237cad257b94c55cb788e8175e474b6696f
commit 996e5237cad257b94c55cb788e8175e474b6696f
Author: Kitware Robot <kwro...@kitware.com>
AuthorDate: Wed Nov 30 00:01:04 2016 -0500
Commit: Kitware Robot <kwro...@kitware.com>
CommitDate: Wed Nov 30 00:01:04 2016 -0500

CMake Nightly Date Stamp

diff --git a/Source/CMakeVersion.cmake b/Source/CMakeVersion.cmake
index 3086639..1144390 100644
--- a/Source/CMakeVersion.cmake
+++ b/Source/CMakeVersion.cmake
@@ -1,5 +1,5 @@
 # CMake version number components.
 set(CMake_VERSION_MAJOR 3)
 set(CMake_VERSION_MINOR 7)
-set(CMake_VERSION_PATCH 20161129)
+set(CMake_VERSION_PATCH 20161130)
 #set(CMake_VERSION_RC 1)

---

Summary of changes:
 Source/CMakeVersion.cmake |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits


Re: [CMake] Function declaration scope

2016-11-29 Thread Alexander Neundorf
On 2016 M11 29, Tue 14:42:49 CET Robert Bielik wrote:
> Hmm.. using v3.7 the answer is no, i.e. a function declared in a subfolder
> will be available in parent scope. Seems a bit odd, doesn't it ?

this has been discussed here just recently...

Functions and macros are global.
Once they are defined, they are available everywhere, also in parent 
directories etc.

Alex

-- 

Powered by www.kitware.com

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Kitware offers various services to support the CMake community. For more 
information on each offering, please visit:

CMake Support: http://cmake.org/cmake/help/support.html
CMake Consulting: http://cmake.org/cmake/help/consulting.html
CMake Training Courses: http://cmake.org/cmake/help/training.html

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Follow this link to subscribe/unsubscribe:
http://public.kitware.com/mailman/listinfo/cmake


[Cmake-commits] CMake branch, next, updated. v3.7.0-1428-gc974715

2016-11-29 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
   via  c974715fbd90bafcc7c639545e748d5a5dca7886 (commit)
   via  67303794f0bd36912cd9e7e7d0402c3c6fc85a11 (commit)
   via  d23a0196844f066047aa6942b69c6e591462df38 (commit)
   via  1afbe7d2cca61ecf483f7697b0141a233508603d (commit)
  from  6fc28b4e5a902faba2cac49158c003d67c3ca1c4 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=c974715fbd90bafcc7c639545e748d5a5dca7886
commit c974715fbd90bafcc7c639545e748d5a5dca7886
Merge: 6fc28b4 6730379
Author: Brad King 
AuthorDate: Tue Nov 29 14:43:35 2016 -0500
Commit: CMake Topic Stage 
CommitDate: Tue Nov 29 14:43:35 2016 -0500

Merge topic 'end-commands' into next

67303794 Combine all unexpected commands to a single class
d23a0196 Set the error after argument expansion in end commands
1afbe7d2 Make error message of standalone endwhile command consistent


https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=67303794f0bd36912cd9e7e7d0402c3c6fc85a11
commit 67303794f0bd36912cd9e7e7d0402c3c6fc85a11
Author: Daniel Pfeifer 
AuthorDate: Sun Nov 27 20:38:57 2016 +0100
Commit: Brad King 
CommitDate: Tue Nov 29 13:53:29 2016 -0500

Combine all unexpected commands to a single class

diff --git a/Source/CMakeLists.txt b/Source/CMakeLists.txt
index f7e0944..5b381b4 100644
--- a/Source/CMakeLists.txt
+++ b/Source/CMakeLists.txt
@@ -440,24 +440,10 @@ set(SRCS
   cmCreateTestSourceList.h
   cmDefinePropertyCommand.cxx
   cmDefinePropertyCommand.h
-  cmElseCommand.cxx
-  cmElseCommand.h
-  cmElseIfCommand.cxx
-  cmElseIfCommand.h
   cmEnableLanguageCommand.cxx
   cmEnableLanguageCommand.h
   cmEnableTestingCommand.cxx
   cmEnableTestingCommand.h
-  cmEndForEachCommand.cxx
-  cmEndForEachCommand.h
-  cmEndFunctionCommand.cxx
-  cmEndFunctionCommand.h
-  cmEndIfCommand.cxx
-  cmEndIfCommand.h
-  cmEndMacroCommand.cxx
-  cmEndMacroCommand.h
-  cmEndWhileCommand.cxx
-  cmEndWhileCommand.h
   cmExecProgramCommand.cxx
   cmExecProgramCommand.h
   cmExecuteProcessCommand.cxx
@@ -612,6 +598,8 @@ set(SRCS
   cmTryCompileCommand.h
   cmTryRunCommand.cxx
   cmTryRunCommand.h
+  cmUnexpectedCommand.cxx
+  cmUnexpectedCommand.h
   cmUnsetCommand.cxx
   cmUnsetCommand.h
   cmUseMangledMesaCommand.cxx
diff --git a/Source/cmCommands.cxx b/Source/cmCommands.cxx
index 103e72c..4c5b093 100644
--- a/Source/cmCommands.cxx
+++ b/Source/cmCommands.cxx
@@ -18,14 +18,8 @@
 #include "cmContinueCommand.h"
 #include "cmCreateTestSourceList.h"
 #include "cmDefinePropertyCommand.h"
-#include "cmElseCommand.h"
 #include "cmEnableLanguageCommand.h"
 #include "cmEnableTestingCommand.h"
-#include "cmEndForEachCommand.h"
-#include "cmEndFunctionCommand.h"
-#include "cmEndIfCommand.h"
-#include "cmEndMacroCommand.h"
-#include "cmEndWhileCommand.h"
 #include "cmExecProgramCommand.h"
 #include "cmExecuteProcessCommand.h"
 #include "cmFileCommand.h"
@@ -74,6 +68,7 @@
 #include "cmTargetLinkLibrariesCommand.h"
 #include "cmTryCompileCommand.h"
 #include "cmTryRunCommand.h"
+#include "cmUnexpectedCommand.h"
 #include "cmUnsetCommand.h"
 #include "cmWhileCommand.h"
 
@@ -82,7 +77,6 @@
 #include "cmAuxSourceDirectoryCommand.h"
 #include "cmBuildNameCommand.h"
 #include "cmCMakeHostSystemInformationCommand.h"
-#include "cmElseIfCommand.h"
 #include "cmExportCommand.h"
 #include "cmExportLibraryDependenciesCommand.h"
 #include "cmFLTKWrapUICommand.h"
@@ -130,14 +124,8 @@ std::vector GetPredefinedCommands()
   commands.push_back(new cmContinueCommand);
   commands.push_back(new cmCreateTestSourceList);
   commands.push_back(new cmDefinePropertyCommand);
-  commands.push_back(new cmElseCommand);
   commands.push_back(new cmEnableLanguageCommand);
   commands.push_back(new cmEnableTestingCommand);
-  commands.push_back(new cmEndForEachCommand);
-  commands.push_back(new cmEndFunctionCommand);
-  commands.push_back(new cmEndIfCommand);
-  commands.push_back(new cmEndMacroCommand);
-  commands.push_back(new cmEndWhileCommand);
   commands.push_back(new cmExecProgramCommand);
   commands.push_back(new cmExecuteProcessCommand);
   commands.push_back(new cmFileCommand);
@@ -189,12 +177,39 @@ std::vector GetPredefinedCommands()
   commands.push_back(new cmUnsetCommand);
   commands.push_back(new cmWhileCommand);
 
+  commands.push_back(new cmUnexpectedCommand(
+"else", "An ELSE command was found outside of a proper "
+"IF ENDIF structure. Or its arguments did not match "
+"the opening IF command."));
+ 

[Cmake-commits] CMake branch, next, updated. v3.7.0-1424-g6fc28b4

2016-11-29 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
   via  6fc28b4e5a902faba2cac49158c003d67c3ca1c4 (commit)
   via  6938772a114099df406bc72cbc98a3c8d57cd458 (commit)
   via  c4d4becf8b79f68534eb8320ccd63218afa4ca31 (commit)
   via  2599f5d64b6d81967de9ba6f11420ec7815f618d (commit)
   via  7052af9d4a4e71f52e98a24969c38e8eb86f317b (commit)
   via  d675004dbac12a938cf60fac39e5b9b81bbb6a99 (commit)
   via  cb4bc19ae1b2f61165543ef926037936b179414d (commit)
   via  59dbd3f891ed79d56df468235c47be3538be734d (commit)
  from  25be059cb83743a37db09b72ccf33862983bb416 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=6fc28b4e5a902faba2cac49158c003d67c3ca1c4
commit 6fc28b4e5a902faba2cac49158c003d67c3ca1c4
Merge: 25be059 6938772
Author: Brad King 
AuthorDate: Tue Nov 29 13:48:00 2016 -0500
Commit: CMake Topic Stage 
CommitDate: Tue Nov 29 13:48:00 2016 -0500

Merge topic 'QtAutogen_tests_update_v2' into next

6938772a QtAutogen tests: Pass Qt compiler features to library targets
c4d4becf QtAutogen tests: Move the complex test case to a subdirectory
2599f5d6 QtAutogen tests: Extend test description in CMakeLists.txt
7052af9d QtAutogen tests: Move independent sameName test to top list of 
CMakeLists.txt
d675004d QtAutogen tests: Rename uiconly target to camel case uicOnly
cb4bc19a QtAutogen tests: Rename rcc_empty target to camel case rccEmpty
59dbd3f8 QtAutogen tests: Rename rcconly target to camel case rccOnly.


https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=6938772a114099df406bc72cbc98a3c8d57cd458
commit 6938772a114099df406bc72cbc98a3c8d57cd458
Author: Sebastian Holtermann 
AuthorDate: Tue Nov 29 18:11:01 2016 +0100
Commit: Sebastian Holtermann 
CommitDate: Tue Nov 29 18:46:39 2016 +0100

QtAutogen tests: Pass Qt compiler features to library targets

diff --git a/Tests/QtAutogen/CMakeLists.txt b/Tests/QtAutogen/CMakeLists.txt
index c0c20f8..c4d0567 100644
--- a/Tests/QtAutogen/CMakeLists.txt
+++ b/Tests/QtAutogen/CMakeLists.txt
@@ -44,6 +44,7 @@ else()
 
 endif()
 
+get_property(QT_COMPILE_FEATURES TARGET ${QT_QTCORE_TARGET} PROPERTY 
INTERFACE_COMPILE_FEATURES)
 include_directories(${CMAKE_CURRENT_BINARY_DIR})
 
 # -- Test: AUTORCC
@@ -72,11 +73,13 @@ target_link_libraries(uicOnly ${QT_LIBRARIES})
 # have an effect on generation if AUTORCC is off.
 add_library(empty STATIC empty.cpp not_generated_file.qrc)
 set_target_properties(empty PROPERTIES AUTORCC OFF)
-
 set_target_properties(empty PROPERTIES AUTOMOC TRUE)
 target_link_libraries(empty no_link_language)
 add_library(no_link_language STATIC empty.h)
 set_target_properties(no_link_language PROPERTIES AUTOMOC TRUE)
+# Pass Qt compiler features to targets that don't link against Qt
+target_compile_features(no_link_language PRIVATE ${QT_COMPILE_FEATURES})
+target_compile_features(empty PRIVATE ${QT_COMPILE_FEATURES})
 
 # -- Test: AUTORCC
 # When a file listed in a .qrc file changes the target must be rebuilt
diff --git a/Tests/QtAutogen/complex/CMakeLists.txt 
b/Tests/QtAutogen/complex/CMakeLists.txt
index d1b34c6..0d44f50 100644
--- a/Tests/QtAutogen/complex/CMakeLists.txt
+++ b/Tests/QtAutogen/complex/CMakeLists.txt
@@ -12,6 +12,9 @@ set(CMAKE_AUTORCC ON)
 # create an executable and two library targets, each requiring automoc:
 add_library(codeeditorLib STATIC codeeditor.cpp)
 add_library(privateSlot OBJECT private_slot.cpp)
+# Pass Qt compiler features to targets that don't link against Qt
+target_compile_features(codeeditorLib PRIVATE ${QT_COMPILE_FEATURES})
+target_compile_features(privateSlot PRIVATE ${QT_COMPILE_FEATURES})
 
 configure_file(generated_resource.qrc.in generated_resource.qrc @ONLY)
 add_custom_command(

https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=c4d4becf8b79f68534eb8320ccd63218afa4ca31
commit c4d4becf8b79f68534eb8320ccd63218afa4ca31
Author: Sebastian Holtermann 
AuthorDate: Fri Nov 25 15:12:04 2016 +0100
Commit: Sebastian Holtermann 
CommitDate: Tue Nov 29 17:16:33 2016 +0100

QtAutogen tests: Move the complex test case to a subdirectory

diff --git a/Tests/CMakeLists.txt b/Tests/CMakeLists.txt
index e914d00..6327f25 100644
--- a/Tests/CMakeLists.txt
+++ b/Tests/CMakeLists.txt
@@ -1243,7 +1243,7 @@ ${CMake_BINARY_DIR}/bin/cmake -DDIR=dev -P 
${CMake_SOURCE_DIR}/Utilities/Release
 set(run_autogen_test ${CMAKE_CTEST_COMMAND} -V)
 set(run_autouic_test ${CMAKE_CTEST_COMMAND} -V)
   else()
-set(run_autogen_test QtAutogen)
+ 

[Cmake-commits] CMake branch, next, updated. v3.7.0-1416-g25be059

2016-11-29 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
   via  25be059cb83743a37db09b72ccf33862983bb416 (commit)
   via  8bced8b18de592b572eb5766c7d36d76ea789d09 (commit)
   via  cd5cff13370f6953497484f6e4b04f957fe9c9a7 (commit)
  from  57b72acd65db3dc86d326967ec0b1a304c57b6fe (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=25be059cb83743a37db09b72ccf33862983bb416
commit 25be059cb83743a37db09b72ccf33862983bb416
Merge: 57b72ac 8bced8b
Author: Brad King 
AuthorDate: Tue Nov 29 11:50:07 2016 -0500
Commit: CMake Topic Stage 
CommitDate: Tue Nov 29 11:50:07 2016 -0500

Merge topic 'update-kwsys' into next

8bced8b1 Merge branch 'upstream-KWSys' into update-kwsys
cd5cff13 KWSys 2016-11-28 (1c7c2139)


https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=8bced8b18de592b572eb5766c7d36d76ea789d09
commit 8bced8b18de592b572eb5766c7d36d76ea789d09
Merge: 44c978a cd5cff1
Author: Brad King 
AuthorDate: Tue Nov 29 11:49:34 2016 -0500
Commit: Brad King 
CommitDate: Tue Nov 29 11:49:34 2016 -0500

Merge branch 'upstream-KWSys' into update-kwsys

* upstream-KWSys:
  KWSys 2016-11-28 (1c7c2139)


https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=cd5cff13370f6953497484f6e4b04f957fe9c9a7
commit cd5cff13370f6953497484f6e4b04f957fe9c9a7
Author: KWSys Upstream 
AuthorDate: Mon Nov 28 09:03:37 2016 -0500
Commit: Brad King 
CommitDate: Tue Nov 29 11:49:33 2016 -0500

KWSys 2016-11-28 (1c7c2139)

Code extracted from:

http://public.kitware.com/KWSys.git

at commit 1c7c2139e773124c0a2b80e10b2840c22a750980 (master).

Upstream Shortlog
-

Brad King (2):
  5e556d53 Refactor CMake policy settings
  cb55cf5a Set CMake Policy CMP0063 to NEW within KWSys

Dāvis Mosāns (1):
  1c7c2139 ConsoleBuf: Fix character handling between buffer boundaries

diff --git a/CMakeLists.txt b/CMakeLists.txt
index a2d313c..b8a9a6b 100644
--- a/CMakeLists.txt
+++ b/CMakeLists.txt
@@ -67,12 +67,15 @@
 # written.
 
 CMAKE_MINIMUM_REQUIRED(VERSION 2.6.3 FATAL_ERROR)
-IF(POLICY CMP0025)
-  CMAKE_POLICY(SET CMP0025 NEW)
-ENDIF()
-IF(POLICY CMP0056)
-  CMAKE_POLICY(SET CMP0056 NEW)
-ENDIF()
+FOREACH(p
+CMP0025 # CMake 3.0, Compiler id for Apple Clang is now AppleClang.
+CMP0056 # CMake 3.2, Honor link flags in try_compile() source-file 
signature.
+CMP0063 # CMake 3.3, Honor visibility properties for all target types.
+)
+  IF(POLICY ${p})
+CMAKE_POLICY(SET ${p} NEW)
+  ENDIF()
+ENDFOREACH()
 SET(CMAKE_LEGACY_CYGWIN_WIN32 0)
 
 #-
diff --git a/ConsoleBuf.hxx.in b/ConsoleBuf.hxx.in
index 717462e..c45a351 100644
--- a/ConsoleBuf.hxx.in
+++ b/ConsoleBuf.hxx.in
@@ -147,42 +147,47 @@ protected:
 return Traits::eof();
   }
   if (m_isConsoleInput) {
-wchar_t wbuffer[128];
+// ReadConsole doesn't tell if there's more input available
+// don't support reading more characters than this
+wchar_t wbuffer[8192];
 DWORD charsRead;
-if (::ReadConsoleW(m_hInput, wbuffer,
-   (sizeof(wbuffer) / sizeof(wbuffer[0])) - 1,
-   , NULL) == 0 ||
+if (ReadConsoleW(m_hInput, wbuffer,
+ (sizeof(wbuffer) / sizeof(wbuffer[0])), ,
+ NULL) == 0 ||
 charsRead == 0) {
   _setg(true);
   return Traits::eof();
 }
-wbuffer[charsRead] = L'\0';
-setBuffer(wbuffer, m_ibuffer);
+setBuffer(std::wstring(wbuffer, charsRead), m_ibuffer);
   } else {
-std::wstring totalBuffer;
 std::wstring wbuffer;
-char buffer[128];
+std::string strbuffer;
 DWORD bytesRead;
-while (::ReadFile(m_hInput, buffer,
-  (sizeof(buffer) / sizeof(buffer[0])) - 1, ,
-  NULL) == 0) {
-  if (::GetLastError() == ERROR_MORE_DATA) {
-buffer[bytesRead] = '\0';
-if (decodeInputBuffer(buffer, wbuffer)) {
-  totalBuffer += wbuffer;
-  continue;
-}
+LARGE_INTEGER size;
+if (GetFileSizeEx(m_hInput, ) == 0) {
+  _setg(true);
+  return Traits::eof();
+}
+char* buffer = new char[size.LowPart];
+while (ReadFile(m_hInput, buffer, 

[Cmake-commits] CMake branch, next, updated. v3.7.0-1413-g57b72ac

2016-11-29 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
   via  57b72acd65db3dc86d326967ec0b1a304c57b6fe (commit)
   via  31e013ae6066067433676c21b8698256404d64f1 (commit)
   via  d639620e14cb25a3bc8039bc2a50bf402b8d2f79 (commit)
  from  d1565ff672b87389f023fdd1932f407428709e54 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=57b72acd65db3dc86d326967ec0b1a304c57b6fe
commit 57b72acd65db3dc86d326967ec0b1a304c57b6fe
Merge: d1565ff 31e013a
Author: Brad King 
AuthorDate: Tue Nov 29 11:04:47 2016 -0500
Commit: CMake Topic Stage 
CommitDate: Tue Nov 29 11:04:47 2016 -0500

Merge topic 'vs15-rename-generator-for-master' into next

31e013ae Merge branch 'vs15-rename-generator' into 
vs15-rename-generator-for-master
d639620e VS: Rename VS 15 generator to 'Visual Studio 15 2017'


https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=31e013ae6066067433676c21b8698256404d64f1
commit 31e013ae6066067433676c21b8698256404d64f1
Merge: 2f7e05f d639620
Author: Brad King 
AuthorDate: Tue Nov 29 10:50:08 2016 -0500
Commit: Brad King 
CommitDate: Tue Nov 29 10:51:35 2016 -0500

Merge branch 'vs15-rename-generator' into vs15-rename-generator-for-master

diff --cc Help/generator/Visual Studio 15 2017.rst
index 2eb9052,18b0131..a88f8bc
--- a/Help/generator/Visual Studio 15 2017.rst
+++ b/Help/generator/Visual Studio 15 2017.rst
@@@ -9,17 -9,8 +9,17 @@@ to specify a target platform name (arch
  For compatibility with CMake versions prior to 3.1, one may specify
  a target platform name optionally at the end of this generator name:
  
- ``Visual Studio 15 Win64``
+ ``Visual Studio 15 2017 Win64``
Specify target platform ``x64``.
  
- ``Visual Studio 15 ARM``
+ ``Visual Studio 15 2017 ARM``
Specify target platform ``ARM``.
 +
 +Toolset Selection
 +^
 +
- The ``v141`` toolset that comes with Visual Studio 15 is selected by
++The ``v141`` toolset that comes with Visual Studio 15 2017 is selected by
 +default.  The :variable:`CMAKE_GENERATOR_TOOLSET` option may be set, perhaps
 +via the :manual:`cmake(1)` ``-T`` option, to specify another toolset.
 +
 +.. include:: VS_TOOLSET_HOST_ARCH.txt
diff --cc Source/cmGlobalVisualStudio15Generator.cxx
index 19b48df,0c6beb2..091a03e
--- a/Source/cmGlobalVisualStudio15Generator.cxx
+++ b/Source/cmGlobalVisualStudio15Generator.cxx
@@@ -3,12 -3,10 +3,12 @@@
  #include "cmGlobalVisualStudio15Generator.h"
  
  #include "cmAlgorithms.h"
 +#include "cmDocumentationEntry.h"
  #include "cmLocalVisualStudio10Generator.h"
  #include "cmMakefile.h"
 +#include "cmVS141CLFlagTable.h"
  
- static const char vs15generatorName[] = "Visual Studio 15";
+ static const char vs15generatorName[] = "Visual Studio 15 2017";
  
  // Map generator name without year to name with year.
  static const char* cmVS15GenName(const std::string& name, std::string& 
genName)
diff --cc Source/cmake.cxx
index 59290ff,f0caf0d..733e0e4
--- a/Source/cmake.cxx
+++ b/Source/cmake.cxx
@@@ -1440,63 -1485,6 +1440,63 @@@ int cmake::ActualConfigure(
return 0;
  }
  
 +void cmake::CreateDefaultGlobalGenerator()
 +{
 +#if defined(_WIN32) && !defined(__CYGWIN__) && !defined(CMAKE_BOOT_MINGW)
 +  std::string found;
 +  // Try to find the newest VS installed on the computer and
 +  // use that as a default if -G is not specified
 +  const std::string vsregBase = "HKEY_LOCAL_MACHINE\\SOFTWARE\\Microsoft\\";
 +  static const char* const vsVariants[] = {
 +/* clang-format needs this comment to break after the opening brace */
 +"VisualStudio\\", "VCExpress\\", "WDExpress\\"
 +  };
 +  struct VSVersionedGenerator
 +  {
 +const char* MSVersion;
 +const char* GeneratorName;
 +  };
 +  static VSVersionedGenerator const vsGenerators[] = {
- { "15.0", "Visual Studio 15" },  //
++{ "15.0", "Visual Studio 15 2017" }, //
 +{ "14.0", "Visual Studio 14 2015" }, //
 +{ "12.0", "Visual Studio 12 2013" }, //
 +{ "11.0", "Visual Studio 11 2012" }, //
 +{ "10.0", "Visual Studio 10 2010" }, //
 +{ "9.0", "Visual Studio 9 2008" },   //
 +{ "8.0", "Visual Studio 8 2005" },   //
 +{ "7.1", "Visual Studio 7 .NET 2003" }
 +  };
 +  static const char* const vsEntries[] = {
 +"\\Setup\\VC;ProductDir", //
 +";InstallDir" //
 +  };
 +  for (VSVersionedGenerator const* g = cmArrayBegin(vsGenerators);
 +   found.empty() && g != cmArrayEnd(vsGenerators); ++g) {
 +for (const char* const* v = cmArrayBegin(vsVariants);
 + found.empty() && v != 

[Cmake-commits] CMake branch, next, updated. v3.7.0-1408-g04b111b

2016-11-29 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
   via  04b111b971f3e8d6f8c891d8f52943a2dca73496 (commit)
   via  f7c2a803a80d41de41f6b4838d49be2f8bae4afc (commit)
  from  841e09299d5dbd91e2915117cbffabe80b29bcb1 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=04b111b971f3e8d6f8c891d8f52943a2dca73496
commit 04b111b971f3e8d6f8c891d8f52943a2dca73496
Merge: 841e092 f7c2a80
Author: Brad King 
AuthorDate: Tue Nov 29 10:06:57 2016 -0500
Commit: CMake Topic Stage 
CommitDate: Tue Nov 29 10:06:57 2016 -0500

Merge topic 'CMakeGraphVizOptions-docs' into next

f7c2a803 CMakeGraphVizOptions: Minor improvements to docs.


https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=f7c2a803a80d41de41f6b4838d49be2f8bae4afc
commit f7c2a803a80d41de41f6b4838d49be2f8bae4afc
Author: Harry Mallon 
AuthorDate: Wed Nov 23 12:04:33 2016 +
Commit: Brad King 
CommitDate: Tue Nov 29 10:05:02 2016 -0500

CMakeGraphVizOptions: Minor improvements to docs.

* Add `GRAPHVIZ_GRAPH_TYPE` options.
* Correct inaccurate usage info.

diff --git a/Modules/CMakeGraphVizOptions.cmake 
b/Modules/CMakeGraphVizOptions.cmake
index e7c4de6..420e3a9 100644
--- a/Modules/CMakeGraphVizOptions.cmake
+++ b/Modules/CMakeGraphVizOptions.cmake
@@ -13,8 +13,8 @@
 # CMake
 # can generate graphviz files, showing the dependencies between the
 # targets in a project and also external libraries which are linked
-# against.  When CMake is run with the --graphviz=foo option, it will
-# produce
+# against.  When CMake is run with the --graphviz=foo.dot option, it will
+# produce:
 #
 # * a foo.dot file showing all dependencies in the project
 # * a foo.dot. file for each target, file showing on which other 
targets the respective target depends
@@ -29,11 +29,18 @@
 #
 # .. variable:: GRAPHVIZ_GRAPH_TYPE
 #
-#  The graph type
+#  The graph type.
 #
 #  * Mandatory : NO
 #  * Default   : "digraph"
 #
+#  Valid graph types are:
+#
+#  * "graph" : Nodes are joined with lines
+#  * "digraph" : Nodes are joined with arrows showing direction
+#  * "strict graph" : Like "graph" but max one line between each node
+#  * "strict digraph" : Like "graph" but max one line between each node in 
each direction
+#
 # .. variable:: GRAPHVIZ_GRAPH_NAME
 #
 #  The graph name.

---

Summary of changes:
 Modules/CMakeGraphVizOptions.cmake |   13 ++---
 1 file changed, 10 insertions(+), 3 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits


Re: [CMake] Function declaration scope

2016-11-29 Thread Robert Bielik
Hmm.. using v3.7 the answer is no, i.e. a function declared in a subfolder will 
be available in parent scope. Seems a bit odd, doesn't it ?

Regards
/R

>-Original Message-
>From: CMake [mailto:cmake-boun...@cmake.org] On Behalf Of Robert Bielik
>Sent: den 29 november 2016 15:22
>To: Cmake@cmake.org
>Subject: [CMake] Function declaration scope
>
>Question: When declaring a function within a sub CMakeLists.txt file, is that
>function "scoped", i.e. non-existing in parent scope ?
>
>Regards
>/Robert
>
>--
>
>Powered by www.kitware.com
>
>Please keep messages on-topic and check the CMake FAQ at:
>http://www.cmake.org/Wiki/CMake_FAQ
>
>Kitware offers various services to support the CMake community. For more
>information on each offering, please visit:
>
>CMake Support: http://cmake.org/cmake/help/support.html
>CMake Consulting: http://cmake.org/cmake/help/consulting.html
>CMake Training Courses: http://cmake.org/cmake/help/training.html
>
>Visit other Kitware open-source projects at
>http://www.kitware.com/opensource/opensource.html
>
>Follow this link to subscribe/unsubscribe:
>http://public.kitware.com/mailman/listinfo/cmake
-- 

Powered by www.kitware.com

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Kitware offers various services to support the CMake community. For more 
information on each offering, please visit:

CMake Support: http://cmake.org/cmake/help/support.html
CMake Consulting: http://cmake.org/cmake/help/consulting.html
CMake Training Courses: http://cmake.org/cmake/help/training.html

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Follow this link to subscribe/unsubscribe:
http://public.kitware.com/mailman/listinfo/cmake


[Cmake-commits] CMake branch, next, updated. v3.7.0-1406-g841e092

2016-11-29 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
   via  841e09299d5dbd91e2915117cbffabe80b29bcb1 (commit)
   via  e390991846825799e619e072a28f1da58b7c89ba (commit)
  from  8b4edc40e64ee1b32d4ebed18dd799ee63a6f785 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=841e09299d5dbd91e2915117cbffabe80b29bcb1
commit 841e09299d5dbd91e2915117cbffabe80b29bcb1
Merge: 8b4edc4 e390991
Author: Brad King 
AuthorDate: Tue Nov 29 09:33:35 2016 -0500
Commit: CMake Topic Stage 
CommitDate: Tue Nov 29 09:33:35 2016 -0500

Merge topic 'msbuild-customization' into next

e3909918 VS: Add option to customize vcxproj user props file


https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=e390991846825799e619e072a28f1da58b7c89ba
commit e390991846825799e619e072a28f1da58b7c89ba
Author: Michael Stürmer 
AuthorDate: Mon Nov 21 16:05:17 2016 +0100
Commit: Brad King 
CommitDate: Tue Nov 29 09:31:30 2016 -0500

VS: Add option to customize vcxproj user props file

Add a `VS_USER_PROPS_CXX` target property to set the user props file of
the generated `.vcxproj` file to be something other than the default
`$(UserRootDir)\\Microsoft.Cpp.$(Platform).user.props`.

diff --git a/Help/manual/cmake-properties.7.rst 
b/Help/manual/cmake-properties.7.rst
index 82d5588..76df602 100644
--- a/Help/manual/cmake-properties.7.rst
+++ b/Help/manual/cmake-properties.7.rst
@@ -284,6 +284,7 @@ Properties on Targets
/prop_tgt/VS_SCC_PROJECTNAME
/prop_tgt/VS_SCC_PROVIDER
/prop_tgt/VS_SDK_REFERENCES
+   /prop_tgt/VS_USER_PROPS_CXX
/prop_tgt/VS_WINDOWS_TARGET_PLATFORM_MIN_VERSION
/prop_tgt/VS_WINRT_COMPONENT
/prop_tgt/VS_WINRT_EXTENSIONS
diff --git a/Help/prop_tgt/VS_USER_PROPS_CXX.rst 
b/Help/prop_tgt/VS_USER_PROPS_CXX.rst
new file mode 100644
index 000..083ce03
--- /dev/null
+++ b/Help/prop_tgt/VS_USER_PROPS_CXX.rst
@@ -0,0 +1,12 @@
+VS_USER_PROPS_CXX
+-
+
+Sets the user props file to be included in the visual studio
+C++ project file. The standard path is
+``$(UserRootDir)\\Microsoft.Cpp.$(Platform).user.props``, which is
+in most cases the same as
+``%LOCALAPPDATA%\\Microsoft\\MSBuild\\v4.0\\Microsoft.Cpp.Win32.user.props``
+or ``%LOCALAPPDATA%\\Microsoft\\MSBuild\\v4.0\\Microsoft.Cpp.x64.user.props``.
+
+The ``*.user.props`` files can be used for Visual Studio wide
+configuration which is independent from cmake.
diff --git a/Help/release/dev/vs-custom-msbuild-props.rst 
b/Help/release/dev/vs-custom-msbuild-props.rst
new file mode 100644
index 000..15a5b0a
--- /dev/null
+++ b/Help/release/dev/vs-custom-msbuild-props.rst
@@ -0,0 +1,9 @@
+vs-custom-msbuild-props
+---
+
+* The :ref:`Visual Studio Generators` for VS 2010 and above can
+  now be fine tuned using custom msbuild .props files.
+  :prop_tgt:`VS_USER_PROPS_CXX` can be
+  used to change the default path of the user .props file from
+  ``$(UserRootDir)\\Microsoft.Cpp.$(Platform).user.props`` to
+  an arbitrary filename.
diff --git a/Source/cmVisualStudio10TargetGenerator.cxx 
b/Source/cmVisualStudio10TargetGenerator.cxx
index 4dabd51..5b99007 100644
--- a/Source/cmVisualStudio10TargetGenerator.cxx
+++ b/Source/cmVisualStudio10TargetGenerator.cxx
@@ -139,7 +139,11 @@ void cmVisualStudio10TargetGenerator::WriteString(const 
char* line,
   (*this->BuildFileStream) << line;
 }
 
-#define VS10_USER_PROPS "$(UserRootDir)\\Microsoft.Cpp.$(Platform).user.props"
+#define VS10_CXX_DEFAULT_PROPS "$(VCTargetsPath)\\Microsoft.Cpp.Default.props"
+#define VS10_CXX_PROPS "$(VCTargetsPath)\\Microsoft.Cpp.props"
+#define VS10_CXX_USER_PROPS   \
+  "$(UserRootDir)\\Microsoft.Cpp.$(Platform).user.props"
+#define VS10_CXX_TARGETS "$(VCTargetsPath)\\Microsoft.Cpp.targets"
 
 void cmVisualStudio10TargetGenerator::Generate()
 {
@@ -345,12 +349,9 @@ void cmVisualStudio10TargetGenerator::Generate()
   }
 
   this->WriteString("\n", 1);
-  this->WriteString("\n",
-1);
+  this->WriteString("\n", 1);
   this->WriteProjectConfigurationValues();
-  this->WriteString(
-"\n", 1);
+  this->WriteString("\n", 1);
   this->WriteString("\n", 1);
   if (this->GlobalGenerator->IsMasmEnabled()) {
 this->WriteString("WriteString("\n", 1);
   this->WriteString("\n", 1);
-  this->WriteString("\n",
-2);
+  {
+std::string props = VS10_CXX_USER_PROPS;
+if (const char* p =
+  this->GeneratorTarget->GetProperty("VS_USER_PROPS_CXX")) {
+ 

[CMake] Function declaration scope

2016-11-29 Thread Robert Bielik
Question: When declaring a function within a sub CMakeLists.txt file, is that 
function "scoped", i.e. non-existing in parent scope ?

Regards
/Robert

-- 

Powered by www.kitware.com

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Kitware offers various services to support the CMake community. For more 
information on each offering, please visit:

CMake Support: http://cmake.org/cmake/help/support.html
CMake Consulting: http://cmake.org/cmake/help/consulting.html
CMake Training Courses: http://cmake.org/cmake/help/training.html

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Follow this link to subscribe/unsubscribe:
http://public.kitware.com/mailman/listinfo/cmake


[Cmake-commits] CMake branch, next, updated. v3.7.0-1404-g8b4edc4

2016-11-29 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
   via  8b4edc40e64ee1b32d4ebed18dd799ee63a6f785 (commit)
   via  88ecfd8ba122133777bb71b027df3684689d4e3a (commit)
  from  58f56ee84fbb17c75eabff3410b8f5b3e56721cb (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=8b4edc40e64ee1b32d4ebed18dd799ee63a6f785
commit 8b4edc40e64ee1b32d4ebed18dd799ee63a6f785
Merge: 58f56ee 88ecfd8
Author: Brad King 
AuthorDate: Tue Nov 29 09:20:33 2016 -0500
Commit: CMake Topic Stage 
CommitDate: Tue Nov 29 09:20:33 2016 -0500

Merge topic 'cpack-ifw-options' into next

88ecfd8b CPackIFW: Add some options


https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=88ecfd8ba122133777bb71b027df3684689d4e3a
commit 88ecfd8ba122133777bb71b027df3684689d4e3a
Author: Konstantin Podsvirov 
AuthorDate: Fri Nov 11 23:51:28 2016 +0300
Commit: Konstantin Podsvirov 
CommitDate: Thu Nov 24 17:05:51 2016 +0300

CPackIFW: Add some options

New options is: DEFAULT, VIRTUAL, FORCED_INSTALLATION,
DISPLAY_NAME, DESCRIPTION and RELEASE_DATE.

Options added for both cpack_ifw_configure_component and
cpack_ifw_configure_component_group command.

diff --git a/Help/release/dev/cpack-ifw-options.rst 
b/Help/release/dev/cpack-ifw-options.rst
new file mode 100644
index 000..cbe0f63
--- /dev/null
+++ b/Help/release/dev/cpack-ifw-options.rst
@@ -0,0 +1,7 @@
+cpack-ifw-options
+-
+
+* The :module:`CPackIFW` module :command:`cpack_ifw_configure_component` and
+  :command:`cpack_ifw_configure_component_group` commands gained a new
+  ``DEFAULT``, ``VIRTUAL``, ``FORCED_INSTALLATION``, ``DISPLAY_NAME``,
+  ``DESCRIPTION`` and ``RELEASE_DATE`` options to more specific configuration.
diff --git a/Modules/CPackIFW.cmake b/Modules/CPackIFW.cmake
index 08078cb..d0d24ba 100644
--- a/Modules/CPackIFW.cmake
+++ b/Modules/CPackIFW.cmake
@@ -198,13 +198,18 @@
 #
 #   ::
 #
-# cpack_ifw_configure_component( [COMMON] [ESSENTIAL]
+# cpack_ifw_configure_component( [COMMON] [ESSENTIAL] [VIRTUAL]
+# [FORCED_INSTALLATION]
 # [NAME ]
+# [DISPLAY_NAME ]
+# [DESCRIPTION ]
 # [VERSION ]
+# [RELEASE_DATE ]
 # [SCRIPT 

[Cmake-commits] CMake branch, next, updated. v3.7.0-1402-g58f56ee

2016-11-29 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
   via  58f56ee84fbb17c75eabff3410b8f5b3e56721cb (commit)
   via  9db0dfd75861aeb40433ad8a566c2a5900976659 (commit)
  from  1059d4176862fd8fac8ecc66c1b56eeadf4cd07c (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=58f56ee84fbb17c75eabff3410b8f5b3e56721cb
commit 58f56ee84fbb17c75eabff3410b8f5b3e56721cb
Merge: 1059d41 9db0dfd
Author: Brad King 
AuthorDate: Tue Nov 29 09:11:11 2016 -0500
Commit: CMake Topic Stage 
CommitDate: Tue Nov 29 09:11:11 2016 -0500

Merge topic 'FindPythonLibs-tolerate-relative-exe' into next

9db0dfd7 FindPythonLibs: Tolerate a non-absolute PYTHON_EXECUTABLE


https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=9db0dfd75861aeb40433ad8a566c2a5900976659
commit 9db0dfd75861aeb40433ad8a566c2a5900976659
Author: Brad King 
AuthorDate: Mon Nov 28 12:46:10 2016 -0500
Commit: Brad King 
CommitDate: Mon Nov 28 12:49:02 2016 -0500

FindPythonLibs: Tolerate a non-absolute PYTHON_EXECUTABLE

The `PYTHON_EXECUTABLE` variable normally contains an absolute path, but
tolerate cases when it does not without calling `get_filename_component`
with an incorrect number of arguments.

Closes: #16452

diff --git a/Modules/FindPythonLibs.cmake b/Modules/FindPythonLibs.cmake
index 1ebbf29..cd623cf 100644
--- a/Modules/FindPythonLibs.cmake
+++ b/Modules/FindPythonLibs.cmake
@@ -42,16 +42,16 @@
 
 # Use the executable's path as a hint
 set(_Python_LIBRARY_PATH_HINT)
-if(PYTHON_EXECUTABLE)
+if(IS_ABSOLUTE "${PYTHON_EXECUTABLE}")
   if(WIN32)
-get_filename_component(_Python_PREFIX ${PYTHON_EXECUTABLE} PATH)
+get_filename_component(_Python_PREFIX "${PYTHON_EXECUTABLE}" PATH)
 if(_Python_PREFIX)
   set(_Python_LIBRARY_PATH_HINT ${_Python_PREFIX}/libs)
 endif()
 unset(_Python_PREFIX)
   else()
-get_filename_component(_Python_PREFIX ${PYTHON_EXECUTABLE} PATH)
-get_filename_component(_Python_PREFIX ${_Python_PREFIX} PATH)
+get_filename_component(_Python_PREFIX "${PYTHON_EXECUTABLE}" PATH)
+get_filename_component(_Python_PREFIX "${_Python_PREFIX}" PATH)
 if(_Python_PREFIX)
   set(_Python_LIBRARY_PATH_HINT ${_Python_PREFIX}/lib)
 endif()

---

Summary of changes:
 Modules/FindPythonLibs.cmake |8 
 1 file changed, 4 insertions(+), 4 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, master, updated. v3.7.0-692-g44c978a

2016-11-29 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, master has been updated
   via  44c978a2dab96b44ed2dd7470f532c4aa4c7da7c (commit)
   via  a04bbcde3d0fe3f550fab5611d4a06dc323b095e (commit)
   via  ca7a52fc59a77fd775a5d3a3b02c66f6acfb7848 (commit)
  from  325e452ea2d9b3224ade47eda24e44bf00a8306d (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
---

Summary of changes:


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, release, updated. v3.7.0-21-ga04bbcd

2016-11-29 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, release has been updated
   via  a04bbcde3d0fe3f550fab5611d4a06dc323b095e (commit)
   via  6f23daea4391c2db8bc27d2e4cb42eac02368822 (commit)
   via  7d433206cf7de8f28aa2d169ed25cd401fcfc413 (commit)
   via  ca7a52fc59a77fd775a5d3a3b02c66f6acfb7848 (commit)
   via  543dcb0ada5047d789a19dbbffa9028cb1b317c7 (commit)
  from  47dd761379cfc55b6630835e2d30d1cd07b15f9a (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
---

Summary of changes:
 Source/cmGlobalXCodeGenerator.cxx  |   44 
 Tests/IncludeDirectories/CMakeLists.txt|4 +-
 .../SystemIncludeDirectories/CMakeLists.txt|   15 ++--
 Utilities/cmlibarchive/libarchive/CMakeLists.txt   |2 +
 .../cmlibarchive/libarchive/archive_cryptor.c  |9 +--
 .../libarchive/archive_cryptor_private.h   |4 +-
 Utilities/cmlibarchive/libarchive/archive_digest.c |   74 ++--
 .../libarchive/archive_digest_private.h|   14 ++--
 Utilities/cmlibarchive/libarchive/archive_hmac.c   |   14 ++--
 .../cmlibarchive/libarchive/archive_hmac_private.h |4 +-
 ...filter_none.c => archive_openssl_evp_private.h} |   41 ++-
 ...ilter_none.c => archive_openssl_hmac_private.h} |   42 +--
 12 files changed, 140 insertions(+), 127 deletions(-)
 copy Utilities/cmlibarchive/libarchive/{archive_read_support_filter_none.c => 
archive_openssl_evp_private.h} (70%)
 copy Utilities/cmlibarchive/libarchive/{archive_read_support_filter_none.c => 
archive_openssl_hmac_private.h} (70%)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, next, updated. v3.7.0-1400-g1059d41

2016-11-29 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
   via  1059d4176862fd8fac8ecc66c1b56eeadf4cd07c (commit)
   via  44c978a2dab96b44ed2dd7470f532c4aa4c7da7c (commit)
   via  a04bbcde3d0fe3f550fab5611d4a06dc323b095e (commit)
   via  ca7a52fc59a77fd775a5d3a3b02c66f6acfb7848 (commit)
  from  67a24b8fd162e4715e95fa0952d6f08c10338de1 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=1059d4176862fd8fac8ecc66c1b56eeadf4cd07c
commit 1059d4176862fd8fac8ecc66c1b56eeadf4cd07c
Merge: 67a24b8 44c978a
Author: Brad King 
AuthorDate: Tue Nov 29 09:02:14 2016 -0500
Commit: Brad King 
CommitDate: Tue Nov 29 09:02:14 2016 -0500

Merge branch 'master' into next


---

Summary of changes:


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, next, updated. v3.7.0-1396-g67a24b8

2016-11-29 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
   via  67a24b8fd162e4715e95fa0952d6f08c10338de1 (commit)
   via  325e452ea2d9b3224ade47eda24e44bf00a8306d (commit)
   via  9e8f74fbb0148f6aa0a026b8610da6d84bbf0366 (commit)
   via  2ee5eac3668ebdcb6dc19c95eaadf3a4b120202b (commit)
   via  839cd16396eec521f0112e4f542fcf347d029620 (commit)
   via  2f7bafd6dacbe83b881866c0c7a00847ef266382 (commit)
   via  4838ca14dfe9ee17b2c788b91227d8f7bf733f06 (commit)
   via  a0af10e42371b17daa51646a3123ec5d8a6d0291 (commit)
   via  dd4e25a5a6ed6b6a7019e46d56e6f4c098c61618 (commit)
   via  2f7e05fbc20150377668a4ea1b114fd1b4d92df6 (commit)
  from  614f1938b1e50a1e74e9252ec6282ab38faebe37 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=67a24b8fd162e4715e95fa0952d6f08c10338de1
commit 67a24b8fd162e4715e95fa0952d6f08c10338de1
Merge: 614f193 325e452
Author: Brad King 
AuthorDate: Tue Nov 29 09:00:55 2016 -0500
Commit: Brad King 
CommitDate: Tue Nov 29 09:00:55 2016 -0500

Merge branch 'master' into next


---

Summary of changes:
 Source/CMakeVersion.cmake |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, master, updated. v3.7.0-678-g2f7bafd

2016-11-29 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, master has been updated
   via  2f7bafd6dacbe83b881866c0c7a00847ef266382 (commit)
   via  6d604c4972d744defe783e7a5f9fbf478eee2dfe (commit)
  from  4838ca14dfe9ee17b2c788b91227d8f7bf733f06 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=2f7bafd6dacbe83b881866c0c7a00847ef266382
commit 2f7bafd6dacbe83b881866c0c7a00847ef266382
Merge: 4838ca1 6d604c4
Author: Brad King 
AuthorDate: Tue Nov 29 08:59:07 2016 -0500
Commit: CMake Topic Stage 
CommitDate: Tue Nov 29 08:59:07 2016 -0500

Merge topic 'try_compile-honor-CMAKE_WARN_DEPRECATED'

6d604c49 try_compile: Honor CMAKE_WARN_DEPRECATED in test project


---

Summary of changes:
 Help/release/dev/try_compile-honor-CMAKE_WARN_DEPRECATED.rst   |6 ++
 Source/cmCoreTryCompile.cxx|2 ++
 Tests/RunCMake/try_compile/RunCMakeTest.cmake  |1 +
 .../{PlatformVariables.cmake => WarnDeprecated.cmake}  |8 ++--
 4 files changed, 11 insertions(+), 6 deletions(-)
 create mode 100644 Help/release/dev/try_compile-honor-CMAKE_WARN_DEPRECATED.rst
 copy Tests/RunCMake/try_compile/{PlatformVariables.cmake => 
WarnDeprecated.cmake} (59%)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, master, updated. v3.7.0-689-g325e452

2016-11-29 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, master has been updated
   via  325e452ea2d9b3224ade47eda24e44bf00a8306d (commit)
   via  745b56f58c8147aa6015a918f3bfd19abc807b48 (commit)
   via  0ab9cb4699dbbba808f243c4dc32aebe23a69a34 (commit)
   via  703d194338039e0231638b1f690748025ecca505 (commit)
  from  9e8f74fbb0148f6aa0a026b8610da6d84bbf0366 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=325e452ea2d9b3224ade47eda24e44bf00a8306d
commit 325e452ea2d9b3224ade47eda24e44bf00a8306d
Merge: 9e8f74f 745b56f
Author: Brad King 
AuthorDate: Tue Nov 29 08:59:20 2016 -0500
Commit: CMake Topic Stage 
CommitDate: Tue Nov 29 08:59:20 2016 -0500

Merge topic 'find-module-cleanup-sweep'

745b56f5 Find*.cmake: drop the comments before including FPHSA
0ab9cb46 FindLibArchive: do not set LibArchive_FOUND explicitly
703d1943 FindLibArchive: use CMAKE_CURRENT_LIST_DIR to find FPHSA


---

Summary of changes:
 Modules/FindALSA.cmake   |2 --
 Modules/FindASPELL.cmake |2 --
 Modules/FindAVIFile.cmake|2 --
 Modules/FindArmadillo.cmake  |7 ---
 Modules/FindBISON.cmake  |2 --
 Modules/FindBZip2.cmake  |2 --
 Modules/FindBullet.cmake |2 --
 Modules/FindCURL.cmake   |2 --
 Modules/FindCoin3D.cmake |4 
 Modules/FindCurses.cmake |2 --
 Modules/FindDart.cmake   |2 --
 Modules/FindEXPAT.cmake  |2 --
 Modules/FindFLEX.cmake   |2 --
 Modules/FindFreetype.cmake   |3 ---
 Modules/FindGIF.cmake|2 --
 Modules/FindGSL.cmake|1 -
 Modules/FindGTK2.cmake   |1 -
 Modules/FindGit.cmake|3 ---
 Modules/FindGnuTLS.cmake |3 ---
 Modules/FindGnuplot.cmake|3 ---
 Modules/FindHSPELL.cmake |3 ---
 Modules/FindHg.cmake |2 --
 Modules/FindIcotool.cmake|2 --
 Modules/FindJPEG.cmake   |2 --
 Modules/FindJasper.cmake |2 --
 Modules/FindJava.cmake   |1 -
 Modules/FindLATEX.cmake  |1 -
 Modules/FindLTTngUST.cmake   |2 --
 Modules/FindLibArchive.cmake |8 +---
 Modules/FindLibXml2.cmake|2 --
 Modules/FindMPEG.cmake   |2 --
 Modules/FindMPEG2.cmake  |3 ---
 Modules/FindMPI.cmake|1 -
 Modules/FindMotif.cmake  |3 ---
 Modules/FindOpenAL.cmake |2 --
 Modules/FindOpenGL.cmake |2 --
 Modules/FindOpenSceneGraph.cmake |1 -
 Modules/FindPNG.cmake|2 --
 Modules/FindPerl.cmake   |2 --
 Modules/FindPerlLibs.cmake   |2 --
 Modules/FindPhysFS.cmake |3 ---
 Modules/FindPythonInterp.cmake   |2 --
 Modules/FindQuickTime.cmake  |2 --
 Modules/FindTCL.cmake|2 --
 Modules/FindTIFF.cmake   |2 --
 Modules/FindTclsh.cmake  |2 --
 Modules/FindWget.cmake   |4 +---
 Modules/FindZLIB.cmake   |2 --
 48 files changed, 2 insertions(+), 111 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, master, updated. v3.7.0-685-g9e8f74f

2016-11-29 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, master has been updated
   via  9e8f74fbb0148f6aa0a026b8610da6d84bbf0366 (commit)
   via  7abb12c826cad6e5847c32d4769c076732581901 (commit)
   via  d3f9f5120c05e4756d7ee1ed81917f74583455a2 (commit)
  from  2ee5eac3668ebdcb6dc19c95eaadf3a4b120202b (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=9e8f74fbb0148f6aa0a026b8610da6d84bbf0366
commit 9e8f74fbb0148f6aa0a026b8610da6d84bbf0366
Merge: 2ee5eac 7abb12c
Author: Brad King 
AuthorDate: Tue Nov 29 08:59:17 2016 -0500
Commit: CMake Topic Stage 
CommitDate: Tue Nov 29 08:59:17 2016 -0500

Merge topic 'FindDevIL-updates'

7abb12c8 FindDevIL: Make the ILUT library optional
d3f9f512 FindDevIL: fail properly when library is not found.


---

Summary of changes:
 Modules/FindDevIL.cmake |4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, master, updated. v3.7.0-655-ga0af10e

2016-11-29 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, master has been updated
   via  a0af10e42371b17daa51646a3123ec5d8a6d0291 (commit)
   via  9e07ffa4e4211ca165f24c1f45744fbe7984a43f (commit)
  from  dd4e25a5a6ed6b6a7019e46d56e6f4c098c61618 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=a0af10e42371b17daa51646a3123ec5d8a6d0291
commit a0af10e42371b17daa51646a3123ec5d8a6d0291
Merge: dd4e25a 9e07ffa
Author: Brad King 
AuthorDate: Tue Nov 29 08:58:59 2016 -0500
Commit: CMake Topic Stage 
CommitDate: Tue Nov 29 08:58:59 2016 -0500

Merge topic 'librhash-left-shift-unsigned'

9e07ffa4 librhash: Avoid signed left-shift overflow in sha256


---

Summary of changes:
 Utilities/cmlibrhash/librhash/sha256.c |4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, master, updated. v3.7.0-680-g839cd16

2016-11-29 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, master has been updated
   via  839cd16396eec521f0112e4f542fcf347d029620 (commit)
   via  9e3164dfa2747bd15c3d3e780875a9b286b765c6 (commit)
  from  2f7bafd6dacbe83b881866c0c7a00847ef266382 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=839cd16396eec521f0112e4f542fcf347d029620
commit 839cd16396eec521f0112e4f542fcf347d029620
Merge: 2f7bafd 9e3164d
Author: Brad King 
AuthorDate: Tue Nov 29 08:59:11 2016 -0500
Commit: CMake Topic Stage 
CommitDate: Tue Nov 29 08:59:11 2016 -0500

Merge topic 'vs-default-build-package'

9e3164df VS: Add option to place `PACKAGE` target in solution default build


---

Summary of changes:
 Help/manual/cmake-variables.7.rst  |1 +
 Help/release/dev/vs-default-build-package.rst  |7 
 .../CMAKE_VS_INCLUDE_PACKAGE_TO_DEFAULT_BUILD.rst  |8 +
 Source/cmGlobalVisualStudio7Generator.cxx  |   35 
 .../VSSolution/AddPackageToDefault-check.cmake |   29 
 .../RunCMake/VSSolution/AddPackageToDefault.cmake  |2 ++
 Tests/RunCMake/VSSolution/RunCMakeTest.cmake   |1 +
 7 files changed, 69 insertions(+), 14 deletions(-)
 create mode 100644 Help/release/dev/vs-default-build-package.rst
 create mode 100644 Help/variable/CMAKE_VS_INCLUDE_PACKAGE_TO_DEFAULT_BUILD.rst
 create mode 100644 Tests/RunCMake/VSSolution/AddPackageToDefault-check.cmake
 create mode 100644 Tests/RunCMake/VSSolution/AddPackageToDefault.cmake


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, master, updated. v3.7.0-653-gdd4e25a

2016-11-29 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, master has been updated
   via  dd4e25a5a6ed6b6a7019e46d56e6f4c098c61618 (commit)
   via  6f23daea4391c2db8bc27d2e4cb42eac02368822 (commit)
   via  7d433206cf7de8f28aa2d169ed25cd401fcfc413 (commit)
  from  2f7e05fbc20150377668a4ea1b114fd1b4d92df6 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=dd4e25a5a6ed6b6a7019e46d56e6f4c098c61618
commit dd4e25a5a6ed6b6a7019e46d56e6f4c098c61618
Merge: 2f7e05f 6f23dae
Author: Brad King 
AuthorDate: Tue Nov 29 08:58:55 2016 -0500
Commit: CMake Topic Stage 
CommitDate: Tue Nov 29 08:58:55 2016 -0500

Merge topic 'libarchive-openssl-1.1'

6f23daea libarchive: Add support for building with OpenSSL 1.1
7d433206 libarchive: Add headers to adapt between OpenSSL 1.1 and older 
versions


---

Summary of changes:
 Utilities/cmlibarchive/libarchive/CMakeLists.txt   |2 +
 .../cmlibarchive/libarchive/archive_cryptor.c  |9 +--
 .../libarchive/archive_cryptor_private.h   |4 +-
 Utilities/cmlibarchive/libarchive/archive_digest.c |   74 ++--
 .../libarchive/archive_digest_private.h|   14 ++--
 Utilities/cmlibarchive/libarchive/archive_hmac.c   |   14 ++--
 .../cmlibarchive/libarchive/archive_hmac_private.h |4 +-
 ...filter_none.c => archive_openssl_evp_private.h} |   41 ++-
 ...ilter_none.c => archive_openssl_hmac_private.h} |   42 +--
 9 files changed, 121 insertions(+), 83 deletions(-)
 copy Utilities/cmlibarchive/libarchive/{archive_read_support_filter_none.c => 
archive_openssl_evp_private.h} (70%)
 copy Utilities/cmlibarchive/libarchive/{archive_read_support_filter_none.c => 
archive_openssl_hmac_private.h} (70%)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, master, updated. v3.7.0-682-g2ee5eac

2016-11-29 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, master has been updated
   via  2ee5eac3668ebdcb6dc19c95eaadf3a4b120202b (commit)
   via  cbccebbac970e37a772ee06ab766b6cbc085532f (commit)
  from  839cd16396eec521f0112e4f542fcf347d029620 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=2ee5eac3668ebdcb6dc19c95eaadf3a4b120202b
commit 2ee5eac3668ebdcb6dc19c95eaadf3a4b120202b
Merge: 839cd16 cbccebb
Author: Brad King 
AuthorDate: Tue Nov 29 08:59:14 2016 -0500
Commit: CMake Topic Stage 
CommitDate: Tue Nov 29 08:59:14 2016 -0500

Merge topic 'FindPkgConfig-fix-print-errors'

cbccebba FindPkgConfig: Fix missing error text when library version is 
specified


---

Summary of changes:
 Modules/FindPkgConfig.cmake |3 ++-
 1 file changed, 2 insertions(+), 1 deletion(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, master, updated. v3.7.0-676-g4838ca1

2016-11-29 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, master has been updated
   via  4838ca14dfe9ee17b2c788b91227d8f7bf733f06 (commit)
   via  4cc601f2c5c0fe76fa76f7e4a47d112df7a1c032 (commit)
   via  7b9131da64b4b569e10ec145fab0c8e22fa69761 (commit)
   via  9cf5b98d54497b425fe341e4ad5bc188d9fa5445 (commit)
   via  a5e806b3f51d91814d8a39a4bb84363d530874bb (commit)
   via  d038559e49b0d0dd65124370f48a92ba3de9006c (commit)
   via  43ce4414c479af6b04e93decaf7f69938c92a323 (commit)
   via  4b316097103e0f30220fd579bce28163d38458bf (commit)
   via  ae05fcc63f37b71cd9b07a2aade03a2a84fa22c4 (commit)
   via  115269a86c3116198f4de7c690fef21ec38767ac (commit)
   via  5dec403103990f766f458ff79987234e3b945787 (commit)
   via  5b20d0abfad057d3d6ae7cbae62f564ddb31dd0f (commit)
   via  489c52ce680df6439f9c1e553cd2925ca8944cb1 (commit)
   via  bbaf24341026cdacd1e313dd3f8e3501e9c4070e (commit)
   via  a92f8d96162b9e6c29ad0bd81b8fd05b387d94a9 (commit)
   via  ec6ce623351ea3fda95dda49a72fc279a63aee87 (commit)
   via  4f5155f6aba7cb7cd8c0e5b75e43b38a70568eb1 (commit)
   via  aaeee1ca72d4f8b09ebf98c3e3bd73d50c09c0d8 (commit)
   via  bf326ebb7694d2e86fbcfef4cb827c70531c3255 (commit)
   via  ce4ec876ceb73f52055b617374c04dbbbfd2a98d (commit)
   via  f8aac21947f43a0e886a3cc3655514abb95bb260 (commit)
  from  a0af10e42371b17daa51646a3123ec5d8a6d0291 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=4838ca14dfe9ee17b2c788b91227d8f7bf733f06
commit 4838ca14dfe9ee17b2c788b91227d8f7bf733f06
Merge: a0af10e 4cc601f
Author: Brad King 
AuthorDate: Tue Nov 29 08:59:03 2016 -0500
Commit: CMake Topic Stage 
CommitDate: Tue Nov 29 08:59:03 2016 -0500

Merge topic 'initial_cuda_language_support'

4cc601f2 Help: Add release note for CUDA support
7b9131da CUDA: Add tests to verify CUDA compiler works properly.
9cf5b98d CUDA: Prefer environment variables CUDACXX and CUDAHOSTCXX.
a5e806b3 CUDA: Add support for CMAKE_CUDA_COMPILE_OPTIONS_VISIBILITY
d038559e CUDA: Add separable compilation support to the makefile generator.
43ce4414 CUDA: Add separable compilation support to the ninja generator.
4b316097 CUDA: Add support for the CUDA_SEPARABLE_COMPILATION target 
property
ae05fcc6 CUDA: Add LinkLineComputer that computes cuda dlink lines.
115269a8 CUDA: Refactor cmLinkLineComputer to allow for better derived 
children.
5dec4031 CUDA: Refactor CMakeCUDAInformation to prepare for separable 
compilation.
5b20d0ab CUDA: C++ compile features now enable cuda c++11 support.
489c52ce CUDA: Use the host compiler for linking CUDA executables and 
shared libs.
bbaf2434 CUDA: add support for specifying an explicit host compiler.
a92f8d96 CUDA: Enable header dependency scanning.
ec6ce623 CUDA: State that cuda has preprocessor output and can generate 
assembly.
4f5155f6 CUDA: We now properly perform CUDA compiler identification.
...


---

Summary of changes:
 Help/manual/cmake-properties.7.rst|1 +
 Help/prop_tgt/CUDA_SEPARABLE_COMPILATION.rst  |   13 +
 Help/release/dev/CUDA-language-support.rst|6 +
 Modules/CMakeCUDACompiler.cmake.in|   20 ++
 Modules/CMakeCUDACompilerABI.cu   |   16 +
 Modules/CMakeCUDACompilerId.cu.in |   39 +++
 Modules/CMakeCUDAInformation.cmake|  193 +++
 Modules/CMakeCompilerIdDetection.cmake|5 +
 Modules/CMakeDetermineCUDACompiler.cmake  |  115 +++
 Modules/CMakeDetermineCompilerId.cmake|6 +-
 Modules/CMakeTestCUDACompiler.cmake   |   71 
 Modules/Compiler/NVIDIA-CUDA.cmake|   24 ++
 Modules/Compiler/NVIDIA-DetermineCompiler.cmake   |7 +
 Source/CMakeLists.txt |2 +
 Source/cmComputeLinkInformation.h |1 +
 Source/cmLinkLineComputer.h   |6 +-
 Source/cmLinkLineDeviceComputer.cxx   |   74 +
 Source/cmLinkLineDeviceComputer.h |   36 +++
 Source/cmLocalGenerator.cxx   |5 +
 Source/cmLocalUnixMakefileGenerator3.cxx  |7 +-
 Source/cmMakefile.cxx |3 +
 Source/cmMakefileExecutableTargetGenerator.cxx|  227 +
 Source/cmMakefileExecutableTargetGenerator.h  |4 +
 Source/cmMakefileLibraryTargetGenerator.cxx   |  222 +
 

[Cmake-commits] CMake branch, next, updated. v3.7.0-1386-g614f193

2016-11-29 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
   via  614f1938b1e50a1e74e9252ec6282ab38faebe37 (commit)
   via  9e3164dfa2747bd15c3d3e780875a9b286b765c6 (commit)
  from  45db27654cf20ced2b6f2936b6b93e91534b82ec (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=614f1938b1e50a1e74e9252ec6282ab38faebe37
commit 614f1938b1e50a1e74e9252ec6282ab38faebe37
Merge: 45db276 9e3164d
Author: Brad King 
AuthorDate: Tue Nov 29 08:46:38 2016 -0500
Commit: CMake Topic Stage 
CommitDate: Tue Nov 29 08:46:38 2016 -0500

Merge topic 'vs-default-build-package' into next

9e3164df VS: Add option to place `PACKAGE` target in solution default build


https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=9e3164dfa2747bd15c3d3e780875a9b286b765c6
commit 9e3164dfa2747bd15c3d3e780875a9b286b765c6
Author: Michael Stürmer 
AuthorDate: Mon Nov 21 13:25:35 2016 +0100
Commit: Brad King 
CommitDate: Tue Nov 29 08:46:27 2016 -0500

VS: Add option to place `PACKAGE` target in solution default build

Add a `CMAKE_VS_INCLUDE_PACKAGE_TO_DEFAULT_BUILD` variable to control
this behavior.

diff --git a/Help/manual/cmake-variables.7.rst 
b/Help/manual/cmake-variables.7.rst
index d68265d..c621d3a 100644
--- a/Help/manual/cmake-variables.7.rst
+++ b/Help/manual/cmake-variables.7.rst
@@ -328,6 +328,7 @@ Variables that Control the Build
/variable/CMAKE_USE_RELATIVE_PATHS
/variable/CMAKE_VISIBILITY_INLINES_HIDDEN
/variable/CMAKE_VS_INCLUDE_INSTALL_TO_DEFAULT_BUILD
+   /variable/CMAKE_VS_INCLUDE_PACKAGE_TO_DEFAULT_BUILD
/variable/CMAKE_WINDOWS_EXPORT_ALL_SYMBOLS
/variable/CMAKE_WIN32_EXECUTABLE
/variable/CMAKE_XCODE_ATTRIBUTE_an-attribute
diff --git a/Help/release/dev/vs-default-build-package.rst 
b/Help/release/dev/vs-default-build-package.rst
new file mode 100644
index 000..62c66e0
--- /dev/null
+++ b/Help/release/dev/vs-default-build-package.rst
@@ -0,0 +1,7 @@
+vs-default-build-package
+
+
+* The :ref:`Visual Studio Generators` for VS 2010 and above now support
+  adding the PACKAGE target to the targets which are built by default.
+  The behavior is similar to 
:variable:`CMAKE_VS_INCLUDE_INSTALL_TO_DEFAULT_BUILD`
+  and can be toggled using 
:variable:`CMAKE_VS_INCLUDE_PACKAGE_TO_DEFAULT_BUILD`.
diff --git a/Help/variable/CMAKE_VS_INCLUDE_PACKAGE_TO_DEFAULT_BUILD.rst 
b/Help/variable/CMAKE_VS_INCLUDE_PACKAGE_TO_DEFAULT_BUILD.rst
new file mode 100644
index 000..693ba45
--- /dev/null
+++ b/Help/variable/CMAKE_VS_INCLUDE_PACKAGE_TO_DEFAULT_BUILD.rst
@@ -0,0 +1,8 @@
+CMAKE_VS_INCLUDE_PACKAGE_TO_DEFAULT_BUILD
+-
+
+Include ``PACKAGE`` target to default build.
+
+In Visual Studio solution, by default the ``PACKAGE`` target will not be part
+of the default build. Setting this variable will enable the ``PACKAGE`` target
+to be part of the default build.
diff --git a/Tests/RunCMake/VSSolution/AddPackageToDefault-check.cmake 
b/Tests/RunCMake/VSSolution/AddPackageToDefault-check.cmake
index 402f6d5..7265900 100644
--- a/Tests/RunCMake/VSSolution/AddPackageToDefault-check.cmake
+++ b/Tests/RunCMake/VSSolution/AddPackageToDefault-check.cmake
@@ -10,7 +10,7 @@ set(packageInBuild FALSE)
 file(STRINGS "${vcSlnFile}" lines)
 foreach(line IN LISTS lines)
   if(NOT packageGuidFound)
-if(line MATCHES "^Project.*\"PACKAGE.vcxproj\".*\"{([A-F0-9-]+)}\"$")
+if(line MATCHES "^Project.*\"PACKAGE.vcx?proj\".*\"{([A-F0-9-]+)}\"$")
   set(packageGuidFound TRUE)
   set(packageGuid ${CMAKE_MATCH_1})
 endif()

---

Summary of changes:
 Tests/RunCMake/VSSolution/AddPackageToDefault-check.cmake |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, next, updated. v3.7.0-1382-gaafa5e7

2016-11-29 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
   via  aafa5e76c80c4850a7767d47fb8026d70b4b9a52 (commit)
   via  9e07ffa4e4211ca165f24c1f45744fbe7984a43f (commit)
  from  35edbdb02c0566eb56c3b649450caf68607b5216 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=aafa5e76c80c4850a7767d47fb8026d70b4b9a52
commit aafa5e76c80c4850a7767d47fb8026d70b4b9a52
Merge: 35edbdb 9e07ffa
Author: Brad King 
AuthorDate: Tue Nov 29 08:31:12 2016 -0500
Commit: CMake Topic Stage 
CommitDate: Tue Nov 29 08:31:12 2016 -0500

Merge topic 'librhash-left-shift-unsigned' into next

9e07ffa4 librhash: Avoid signed left-shift overflow in sha256


https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=9e07ffa4e4211ca165f24c1f45744fbe7984a43f
commit 9e07ffa4e4211ca165f24c1f45744fbe7984a43f
Author: Brad King 
AuthorDate: Tue Nov 29 08:28:31 2016 -0500
Commit: Brad King 
CommitDate: Tue Nov 29 08:30:25 2016 -0500

librhash: Avoid signed left-shift overflow in sha256

Fix `rhash_sha256_final` to use unsigned integers for left shifting to
avoid the possibility of undefined overflow behavior.

diff --git a/Utilities/cmlibrhash/librhash/sha256.c 
b/Utilities/cmlibrhash/librhash/sha256.c
index 064dfe2..af5b0fe 100644
--- a/Utilities/cmlibrhash/librhash/sha256.c
+++ b/Utilities/cmlibrhash/librhash/sha256.c
@@ -218,8 +218,8 @@ void rhash_sha256_final(sha256_ctx *ctx, unsigned char* 
result)
/* pad message and run for last block */
 
/* append the byte 0x80 to the message */
-   ctx->message[index]   &= le2me_32(~(0x << shift));
-   ctx->message[index++] ^= le2me_32(0x80 << shift);
+   ctx->message[index]   &= le2me_32(~(0xu << shift));
+   ctx->message[index++] ^= le2me_32(0x80u << shift);
 
/* if no room left in the message to store 64-bit message length */
if (index > 14) {

---

Summary of changes:
 Utilities/cmlibrhash/librhash/sha256.c |4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)


hooks/post-receive
diff --git a/Source/cmGlobalVisualStudio7Generator.cxx 
b/Source/cmGlobalVisualStudio7Generator.cxx
index c60a1ff..602666e 100644
--- a/Source/cmGlobalVisualStudio7Generator.cxx
+++ b/Source/cmGlobalVisualStudio7Generator.cxx
@@ -681,20 +681,27 @@ std::set 
cmGlobalVisualStudio7Generator::IsPartOfDefaultBuild(
   // default build if another target depends on it
   int type = target->GetType();
   if (type == cmStateEnums::GLOBAL_TARGET) {
-// check if INSTALL target is part of default build
-if (target->GetName() == "INSTALL") {
-  // inspect CMAKE_VS_INCLUDE_INSTALL_TO_DEFAULT_BUILD properties
-  for (std::vector::const_iterator i = configs.begin();
-   i != configs.end(); ++i) {
-const char* propertyValue =
-  target->Target->GetMakefile()->GetDefinition(
-"CMAKE_VS_INCLUDE_INSTALL_TO_DEFAULT_BUILD");
-cmGeneratorExpression ge;
-CM_AUTO_PTR cge =
-  ge.Parse(propertyValue);
-if (cmSystemTools::IsOn(
-  cge->Evaluate(target->GetLocalGenerator(), *i))) {
-  activeConfigs.insert(*i);
+std::list targetNames;
+targetNames.push_back("INSTALL");
+targetNames.push_back("PACKAGE");
+for (std::list::const_iterator t = targetNames.begin();
+ t != targetNames.end(); ++t) {
+  // check if target <*t> is part of default build
+  if (target->GetName() == *t) {
+const std::string propertyName =
+  "CMAKE_VS_INCLUDE_" + *t + "_TO_DEFAULT_BUILD";
+// inspect CMAKE_VS_INCLUDE_<*t>_TO_DEFAULT_BUILD properties
+for 

[Cmake-commits] CMake branch, next, updated. v3.7.0-1384-g45db276

2016-11-29 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
   via  45db27654cf20ced2b6f2936b6b93e91534b82ec (commit)
   via  51c964511ee52c89370e15fd7968d54368e7cb3e (commit)
  from  aafa5e76c80c4850a7767d47fb8026d70b4b9a52 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=45db27654cf20ced2b6f2936b6b93e91534b82ec
commit 45db27654cf20ced2b6f2936b6b93e91534b82ec
Merge: aafa5e7 51c9645
Author: Brad King 
AuthorDate: Tue Nov 29 08:46:01 2016 -0500
Commit: CMake Topic Stage 
CommitDate: Tue Nov 29 08:46:01 2016 -0500

Merge topic 'vs-default-build-package' into next

51c96451 fixup! VS: Add option to place `PACKAGE` target in solution 
default build


https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=51c964511ee52c89370e15fd7968d54368e7cb3e
commit 51c964511ee52c89370e15fd7968d54368e7cb3e
Author: Brad King 
AuthorDate: Tue Nov 29 08:45:35 2016 -0500
Commit: Brad King 
CommitDate: Tue Nov 29 08:45:35 2016 -0500

fixup! VS: Add option to place `PACKAGE` target in solution default build

-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits


Re: [cmake-developers] GitLab speed

2016-11-29 Thread Stuermer, Michael SP/HZA-ZSEP
>From my side access to the web interface as well as repo handling is also 
>slower than github. I personally consider this more to be a luxury problem 
>than a real issue. Would be great if were faster but it works well for me. On 
>the other hand I like the whole workflow, that is great!

I suppose the whole repo infrastructure is hosted at kitware and the 
bandwidth to the internet is just limited at some point.

> -Original Message-
> From: cmake-developers [mailto:cmake-developers-boun...@cmake.org]
> On Behalf Of Harry Mallon
> Sent: Tuesday, November 29, 2016 11:02 AM
> To: cmake-developers@cmake.org
> Cc: Harry Mallon
> Subject: Re: [cmake-developers] GitLab speed
> 
> Hi Brad,
> 
> 
> Harry Mallon
> CODEX | Software Engineer
> 60 Poland Street | London | England | W1F 7NT E ha...@codexdigital.com | T
> +44 203 7000 989
> > On 28 Nov 2016, at 20:01, Brad King  wrote:
> >
> > On 11/28/2016 02:27 PM, Harry Mallon wrote:
> >> moving around the interface and even pushing to repos seems to be
> >> much slower than the equivalent thing on github.
> >
> > Has it only been today or the last few days that you've noticed this?
> > It does feel slower today than usual.  I'll check with our admins.
> 
> I am not sure of the answer to this. I have only just moved over to prepare a
> tiny merge request.
> 
> >
> >> I am not sure whether this report is constructive
> >
> > It is legitimate feedback presented in a civil tone.
> >
> > Thanks,
> > -Brad
> >
> 
> Harry
> 
> --
> 
> Powered by www.kitware.com
> 
> Please keep messages on-topic and check the CMake FAQ at:
> http://www.cmake.org/Wiki/CMake_FAQ
> 
> Kitware offers various services to support the CMake community. For more
> information on each offering, please visit:
> 
> CMake Support: http://cmake.org/cmake/help/support.html
> CMake Consulting: http://cmake.org/cmake/help/consulting.html
> CMake Training Courses: http://cmake.org/cmake/help/training.html
> 
> Visit other Kitware open-source projects at
> http://www.kitware.com/opensource/opensource.html
> 
> Follow this link to subscribe/unsubscribe:
> http://public.kitware.com/mailman/listinfo/cmake-developers
-- 

Powered by www.kitware.com

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Kitware offers various services to support the CMake community. For more 
information on each offering, please visit:

CMake Support: http://cmake.org/cmake/help/support.html
CMake Consulting: http://cmake.org/cmake/help/consulting.html
CMake Training Courses: http://cmake.org/cmake/help/training.html

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Follow this link to subscribe/unsubscribe:
http://public.kitware.com/mailman/listinfo/cmake-developers